@@ -40,7 +40,7 @@
  *
  */
 /*
- * $Id: mboxlist.c,v 1.219.2.1 2003/11/04 21:39:18 rjs3 Exp $
+ * $Id: mboxlist.c,v 1.219.2.3 2004/02/26 22:56:56 rjs3 Exp $
  */
 
 #include <config.h>
@@ -855,7 +855,7 @@ int mboxlist_deletemailbox(const char *name, int isadmin, char *userid,
 	if (!isadmin) { r = IMAP_PERMISSION_DENIED; goto done; }
     }
 
-    r = mboxlist_mylookup(name, &mbtype, &path, NULL, &acl, NULL, 1);
+    r = mboxlist_mylookup(name, &mbtype, &path, NULL, &acl, &tid, 1);
     switch (r) {
     case 0:
 	break;
@@ -1998,7 +1998,7 @@ int mboxlist_findall_alt(struct namespace *namespace,
 		cbrock.checkshared = 1;
 	    }
 
-	    if (cbrock.checkshared && !*p) {
+	    if ((cbrock.checkshared || prefixlen == len) && !*p) {
 		/* special case:  LIST "" % -- output prefix
 		   (if we have a shared mbox) and quit */
 		cbrock.g = glob_init("*", GLOB_HIERARCHY);
@@ -2720,7 +2720,7 @@ int mboxlist_findsub_alt(struct namespace *namespace,
 		cbrock.checkshared = 1;
 	    }
 
-	    if (cbrock.checkshared && !*p) {
+	    if ((cbrock.checkshared || prefixlen == len) && !*p) {
 		/* special case:  LSUB "" % -- output prefix
 		   (if we have a shared mbox) and quit */
 		cbrock.g = glob_init("*", GLOB_HIERARCHY);
