@@ -40,7 +40,7 @@
  */
 
 /*
- * $Id: pop3d.c,v 1.142 2003/09/03 14:38:25 ken3 Exp $
+ * $Id: pop3d.c,v 1.142.2.3 2004/03/26 02:03:55 ken3 Exp $
  */
 #include <config.h>
 
@@ -122,9 +122,10 @@ struct msg {
     unsigned uid;
     unsigned size;
     int deleted;
-} *popd_msg;
+} *popd_msg = NULL;
 
 static int pop3s = 0;
+static int pop3_logfd = -1;
 int popd_starttls_done = 0;
 
 static struct mailbox mboxstruct;
@@ -189,6 +190,11 @@ static void popd_reset(void)
 {
     proc_cleanup();
 
+    if (pop3_logfd != -1) {
+        close(pop3_logfd);
+        pop3_logfd = -1;
+    }
+
     if (popd_mailbox) {
 	mailbox_close(popd_mailbox);
 	popd_mailbox = 0;
@@ -432,6 +438,9 @@ void shut_down(int code)
     if (popd_mailbox) {
 	mailbox_close(popd_mailbox);
     }
+    if (popd_msg) {
+	free(popd_msg);
+    }
     mboxlist_close();
     mboxlist_done();
 
@@ -1311,7 +1320,8 @@ int openinbox(void)
     if (!r) {
 	popd_exists = mboxstruct.exists;
 	popd_highest = 0;
-	popd_msg = (struct msg *)xmalloc((popd_exists+1) * sizeof(struct msg));
+	popd_msg = (struct msg *) xrealloc(popd_msg, (popd_exists+1) *
+					   sizeof(struct msg));
 	for (msg = 1; msg <= popd_exists; msg++) {
 	    if ((r = mailbox_read_index_record(&mboxstruct, msg, &record))!=0)
 	      break;
@@ -1324,9 +1334,7 @@ int openinbox(void)
 	mailbox_close(&mboxstruct);
 	free(popd_userid);
 	popd_userid = 0;
-	free(popd_msg);
-	popd_msg = 0;
-	popd_exists = 0;
+ 	popd_exists = 0;
 	prot_printf(popd_out, "-ERR [SYS/PERM] Unable to read maildrop\r\n");
 	return 1;
     }
@@ -1334,7 +1342,7 @@ int openinbox(void)
     proc_register("pop3d", popd_clienthost, popd_userid, popd_mailbox->name);
 
     /* Create telemetry log */
-    telemetry_log(popd_userid, popd_in, popd_out, 0);
+    pop3_logfd=telemetry_log(popd_userid, popd_in, popd_out, 0);
 
     prot_printf(popd_out, "+OK Maildrop locked and ready\r\n");
     return 0;
