@@ -40,7 +40,7 @@
  */
 
 /*
- * $Id: pop3proxyd.c,v 1.62 2003/07/22 19:17:17 rjs3 Exp $
+ * $Id: pop3proxyd.c,v 1.62.2.1 2004/02/16 22:13:04 rjs3 Exp $
  */
 #include <config.h>
 
@@ -1167,7 +1167,7 @@ static int proxy_authenticate(const char *hostname, char **authline_status)
 
     /* we now do the actual SASL exchange */
     r = sasl_client_start(backend_saslconn, 
-			  config_getstring(buf, "KERBEROS_V4"),
+			  config_getstring(buf, NULL),
 			  NULL, &out, &outlen, &mechusing);
     if ((r != SASL_OK) && (r != SASL_CONTINUE)) {
 	return r;
