@@ -39,7 +39,7 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-/* $Id: master.c,v 1.83 2003/09/04 19:57:57 rjs3 Exp $ */
+/* $Id: master.c,v 1.83.2.1 2003/12/18 16:29:54 rjs3 Exp $ */
 
 #include <config.h>
 
@@ -1624,7 +1624,8 @@ int main(int argc, char **argv)
 		process_msg(&Services[i], msg);
 	    }
 
-	    if (Services[i].nactive < Services[i].max_workers) {
+	    if (Services[i].exec &&
+		Services[i].nactive < Services[i].max_workers) {
 		/* bring us up to desired_workers */
 		for (j = Services[i].ready_workers;
 		     j < Services[i].desired_workers; 
